@@ -8,11 +8,12 @@ from datatypes import (
     Pool,
     EnglishWord,
     NamingConvention,
+    classproperty
 )
 
 # first party
 from .query import Query, Iterator
-from . import decorators, utils
+from . import utils
 from .interface import get_interface
 from .config import (
     Schema,
@@ -83,14 +84,14 @@ class Orm(object):
     _created = AutoDatetime(created=True, updated=False, aliases=["created"])
     _updated = AutoDatetime(created=False, updated=True, aliases=["updated"])
 
-    @decorators.classproperty
+    @classproperty
     def table_name(cls):
         return NamingConvention("{}_{}".format(
             cls.__module__.replace(".", "_"),
             cls.__name__
         )).snakecase()
 
-    @decorators.classproperty
+    @classproperty
     def model_name(cls):
         """Returns the name for this orm
 
@@ -105,7 +106,7 @@ class Orm(object):
         """
         return NamingConvention(cls.__name__).snakecase()
 
-    @decorators.classproperty
+    @classproperty
     def models_name(cls):
         """Returns the plural name for this orm
 
@@ -114,12 +115,12 @@ class Orm(object):
         """
         return EnglishWord(cls.model_name).plural()
 
-    @decorators.classproperty
+    @classproperty
     def schema(cls):
         """the Schema() instance that this class will derive all its db info from"""
         return Schema.get_instance(cls)
 
-    @decorators.classproperty
+    @classproperty
     def interface(cls):
         """
         return an Interface instance that can be used to access the db
@@ -128,7 +129,7 @@ class Orm(object):
         """
         return get_interface(cls.connection_name)
 
-    @decorators.classproperty
+    @classproperty
     def query(cls):
         """return a new Query instance ready to make a db call using the child class
 
@@ -341,8 +342,8 @@ class Orm(object):
     def to_interface(self):
         """Get all the fields that need to be saved
 
-        :param is_udpate: bool, True if update query, False if insert
-        :returns: dict, key is field_name and val is the field value to be saved
+        :returns: dict[str, Any], key is field_name and val is the field value
+            to be saved
         """
         fields = {}
         schema = self.schema
@@ -351,6 +352,9 @@ class Orm(object):
 
             is_modified = field.modified(self, v)
             if is_modified:
+                if not field.options.get("empty", True) and not v:
+                    raise ValueError(f"{self.__class__.__name__}.{k} cannot be empty")
+
                 fields[k] = v
 
             if v is None and field.is_required():
@@ -360,7 +364,7 @@ class Orm(object):
 
                 else:
                     if self.is_insert() or is_modified:
-                        raise KeyError("Missing required field {}".format(k))
+                        raise KeyError(f"Missing required field {self.__class__.__name__}.{k}")
 
         return fields
 
@@ -693,10 +697,12 @@ class Orm(object):
         like dictify() though, but I've already used this method in so many places
         """
         d = {}
-        #for field_name, field in self.schema.normal_fields.items():
         for field_name, field in self.schema.fields.items():
-            field_val = getattr(self, field_name, None)
-            field_val = field.jsonable(self, field_val)
+            field_name, field_val = field.jsonable(
+                self,
+                field_name,
+                getattr(self, field_name, None)
+            )
             if field_val is not None:
                 d[field_name] = field_val
 
